@@ -211,7 +211,7 @@ class CogniteGeospatialClient:
             response = yield self.api.by_ids_spatial_items(project, spatial_by_ids)
             if response is not None:
                 items = response.items
-                if len(items) > 0:
+                if items is not None and len(items) > 0:
                     return items[0]
             return None
         except ApiException as e:
@@ -224,6 +224,33 @@ class CogniteGeospatialClient:
         item = self._run_sync(run_func, self.timeout)
         return item
 
+    @gen.coroutine
+    def delete_spatial_async(self, id: int = None, external_id: str = None):
+        """Delete spatial item by internal ids or external ids.
+        """
+        _check_either_external_id(id, external_id)
+        if id is not None:
+            item = InternalIdDTO(id=id)
+        elif external_id is not None:
+            item = ExternalIdDTO(external_id=external_id)
+        spatial_by_ids = SpatialIdsDTO(items=[item])
+        try:
+            response = yield self.api.delete_spatial(self.project, spatial_by_ids)
+            if response is not None:
+                items = response.items
+                if items is not None and len(items) > 0:
+                    return items[0]
+            return None
+        except ApiException as e:
+            _throw_exception(e)
+
+    def delete_spatial(self, id: int = None, external_id: str = None):
+        """Delete spatial item by internal ids or external ids.
+        """
+        run_func = partial(self.delete_spatial_async, id, external_id)
+        item = self._run_sync(run_func, self.timeout)
+        return item
+
     @gen.coroutine
     def get_spatial_async(self, id: int = None, external_id: str = None, project: str = None):
         """Retrieves spatial item data by internal ids or external ids.
@@ -623,21 +650,28 @@ class CogniteGeospatialClient:
         return result
 
     @gen.coroutine
-    def add_spatial_item_data_async(self, id: int, name: str, timestamp: int, type, value):
+    def add_spatial_item_data_async(self, id: int, name: str, type, value):
         value_buff = None
         if type == SpatialDataTypeDTO.DOUBLE:
             value_buff = value.astype(">d").tobytes()
         elif type == SpatialDataTypeDTO.INTEGER:
             value_buff = value.astype(">i").tobytes()
         elif type == SpatialDataTypeDTO.BOOLEAN:
-            value_buff = value.astype(">b").tobytes()
+            pack_int = np.packbits(value, bitorder="big")  # uint8
+            # the end of bit set should be 1, to know the size of it
+            size = len(value)
+            if size % 8 == 0:
+                # bit set is full add one more item
+                pack_int = np.append(pack_int, np.array([0], dtype="uint8"))
+            pack_int[-1] = pack_int[-1] | (1 << (7 - size % 8))  # update last word
+            value_buff = pack_int.tobytes()
         elif type == SpatialDataTypeDTO.TEXT:
             value_buff = bytearray(value, encoding="utf-8")
 
         byte_buffer = base64.urlsafe_b64encode(value_buff)
 
         spatial_data = SpatialDataDTO(
-            item_id=InternalIdDTO(id=id), name=name, type=type, value=str(byte_buffer, "utf-8"), timestamp=timestamp
+            item_id=InternalIdDTO(id=id), name=name, type=type, value=str(byte_buffer, "utf-8")
         )
 
         try:
@@ -707,7 +741,6 @@ class CogniteGeospatialClient:
             if items is not None and len(items) > 0:
                 item = items[0]
         if item is not None:
-            timestamp = round(time.monotonic() * 1000)
             for name in data:
                 vector = data[name]
                 spatial_type = None
@@ -721,7 +754,7 @@ class CogniteGeospatialClient:
                 elif vector.dtype == "bool":
                     spatial_type = SpatialDataTypeDTO.BOOLEAN
 
-                r = yield self.add_spatial_item_data_async(item.id, name, timestamp, spatial_type, vector)
+                r = yield self.add_spatial_item_data_async(item.id, name, spatial_type, vector)
 
         yield self.calculate_spatial_coverage_async(id=item.id)
         return item
